@@ -28,6 +28,7 @@
 #include <libgen.h>
 #include <sys/types.h>
 #include <fcntl.h>
+#include <time.h>
 
 int microfeed_debug_memory = 0;
 
@@ -136,7 +137,7 @@ char* microfeed_util_string_append(char* s, ...) {
 	result = (char*)malloc(length);
 	memcpy(result, s, length);
 	va_start(argp, s);
-	while ((s = va_arg(argp, const char*))) {
+	while ((s = va_arg(argp, char*))) {
 		length = strlen(s);
 		result = realloc(result, size + length + 1);
 		memcpy(result + size, s, length + 1);
@@ -283,6 +284,19 @@ char* microfeed_util_string_percent_encoding_unescape(const char* s) {
 	return result;
 }
 
+char* microfeed_util_create_unique_identifier(void) {
+	struct timespec now;
+	char buffer[1024];
+	
+	if (!(clock_gettime(CLOCK_REALTIME, &now))) {
+		snprintf(buffer, 1024, "%lx.%lx", (long)now.tv_sec, now.tv_nsec);
+	} else {
+		buffer[0] = 0;
+	}
+	
+	return strdup(buffer);
+}
+
 int microfeed_util_create_directory_recursively(const char* directory) {
 	int retval = 0;
 	char* s1;
@@ -345,6 +359,38 @@ int microfeed_util_file_copy(const char* source_path, const char* destination_pa
 	return retval;
 }
 
+int microfeed_util_file_exists(const char* path) {
+	int retval = 0;
+	int fd;
+	
+	if ((fd = open(path, O_RDONLY)) >= 0) {
+		retval = 1;
+		close(fd);
+	}
+	
+	return retval;
+}
+
+int microfeed_util_file_create(const char* path, const void* data, size_t data_size) {
+	int retval = 0;
+	int fd;
+	ssize_t wrote;
+	
+	if ((fd = open(path, O_WRONLY | O_CREAT | O_TRUNC, 0666)) >= 0) {
+		while ((wrote = write(fd, data, data_size)) != data_size && wrote >= 0) {
+			data += wrote;
+			data_size -= wrote;		
+		}
+		if (wrote >= 0) {
+			retval = 1;
+		}
+
+		close(fd);
+	}
+
+	return retval;
+}
+
 void microfeed_assert_failed(const char* text) {
 	fprintf(stderr, "\n*****\nAssertion failed: %s\n\n*****\n\n", text);
 	abort();
