@@ -49,10 +49,12 @@ char* microfeed_util_string_percent_encoding_escape(const char* s);
 char* microfeed_util_string_percent_encoding_unescape(const char* s);
 char* microfeed_util_string_base64_encode(const char* s, size_t length);
 size_t microfeed_util_string_starts_with(const char* s, const char* prefix);
+char* microfeed_util_create_unique_identifier(void);
 
 int microfeed_util_create_directory_recursively(const char* directory);
-
 int microfeed_util_file_copy(const char* source_path, const char* destination_path);
+int microfeed_util_file_exists(const char* path);
+int microfeed_util_file_create(const char* path, const void* data, size_t data_size);
 
 void microfeed_assert_failed(const char* text);
 
