@@ -105,7 +105,8 @@
 #define MICROFEED_ERROR_NO_SUCH_FEED "NoSuchFeed"
 #define MICROFEED_ERROR_NO_SUCH_ITEM "NoSuchItem"
 #define MICROFEED_ERROR_NO_SUCH_PROPERTY "NoSuchProperty"
-#define MICROFEED_ERROR_NO_ITEM_DATA "NoItemData"
+#define MICROFEED_ERROR_NO_SUCH_DATA "NoSuchData"
+#define MICROFEED_ERROR_DATA_NOT_SUPPORTED "DataNotSupported"
 #define MICROFEED_ERROR_CANNOT_MODIFY_ITEM "CannotModifyItem"
 #define MICROFEED_ERROR_CONNECTION_FAILED "ConnectionFailed"
 #define MICROFEED_ERROR_LOGIN_FAILED "LoginFailed"
@@ -119,13 +120,13 @@
 #define MICROFEED_METHOD_NAME_UNSUBSCRIBE_FEED "UnsubscribeFeed"
 #define MICROFEED_METHOD_NAME_UPDATE_FEED "UpdateFeed"
 #define MICROFEED_METHOD_NAME_REPUBLISH_ITEMS "RepublishItems"
-#define MICROFEED_METHOD_NAME_SEND_ITEM_DATA "SendItemData"
+#define MICROFEED_METHOD_NAME_STORE_DATA "StoreData"
 #define MICROFEED_METHOD_NAME_CREATE_PUBLISHER "CreatePublisher"
 #define MICROFEED_METHOD_NAME_DESTROY_PUBLISHER "DestroyPublisher"
 #define MICROFEED_METHOD_NAME_MARK_ITEM "MarkItem"
 #define MICROFEED_METHOD_NAME_UNMARK_ITEM "UnmarkItem"
 #define MICROFEED_METHOD_NAME_PING "Ping"
-#define MICROFEED_METHOD_NAME_READ_ITEMS "ReadItems"
+#define MICROFEED_METHOD_NAME_READ_ITEM "ReadItem"
 
 #define MICROFEED_SIGNAL_NAME_FEED_UPDATE_STARTED "FeedUpdateStarted"
 #define MICROFEED_SIGNAL_NAME_FEED_UPDATE_ENDED "FeedUpdateEnded"
@@ -136,37 +137,41 @@
 #define MICROFEED_SIGNAL_NAME_ITEM_REPUBLISHED "ItemRepublished"
 #define MICROFEED_SIGNAL_NAME_ITEM_REMOVED "ItemRemoved"
 #define MICROFEED_SIGNAL_NAME_ITEM_STATUS_CHANGED "ItemStatusChanged"
-#define MICROFEED_SIGNAL_NAME_ITEM_DATA "ItemData"
+#define MICROFEED_SIGNAL_NAME_DATA_STORED "DataStored"
 
-#define MICROFEED_FEED_URI_IMAGES "http://microfeed.org/Feed/Images"
-#define MICROFEED_FEED_URI_OVERVIEW "http://microfeed.org/Feed/Overview"
-#define MICROFEED_FEED_URI_SETTINGS "http://microfeed.org/Feed/Settings"
-#define MICROFEED_FEED_URI_CONTACTS "http://microfeed.org/Feed/Contacts"
-#define MICROFEED_FEED_URI_USER_PREFIX "http://microfeed.org/Feed/User/"
+#define MICROFEED_FEED_URI_OVERVIEW ":Overview"
+#define MICROFEED_FEED_URI_SETTINGS ":Settings"
+#define MICROFEED_FEED_URI_CONTACTS ":Contacts"
+#define MICROFEED_FEED_URI_USER_PREFIX ":User/"
+#define MICROFEED_FEED_URI_COMMENTS_PREFIX ":Comments/"
 
-#define MICROFEED_ITEM_UID_FEED_METADATA "http://microfeed.org/Metadata/Feed"
+#define MICROFEED_ITEM_UID_FEED_METADATA ":Metadata"
 
 #define MICROFEED_ITEM_PERMISSION_NAME_MODIFY ":modify"
-#define MICROFEED_ITEM_PERMISSION_NAME_REMOVE ":remove"
+#define MICROFEED_ITEM_PERMISSION_NAME_DELETE ":delete"
 #define MICROFEED_ITEM_PERMISSION_NAME_REPLY ":reply"
 
 #define MICROFEED_FEED_PERMISSION_NAME_ADD ":add"
 
 #define MICROFEED_ITEM_PROPERTY_NAME_CONTENT_IMAGE "content.image"
 #define MICROFEED_ITEM_PROPERTY_NAME_CONTENT_TEXT "content.text"
-#define MICROFEED_ITEM_PROPERTY_NAME_USER_NICK "user.nick"
-#define MICROFEED_ITEM_PROPERTY_NAME_USER_NAME "user.name"
 #define MICROFEED_ITEM_PROPERTY_NAME_USER_IMAGE "user.image"
-#define MICROFEED_ITEM_PROPERTY_NAME_USER_URI "user.uri"
-#define MICROFEED_ITEM_PROPERTY_NAME_REFERRED_URI "referred.uri"
-#define MICROFEED_ITEM_PROPERTY_NAME_REFERRED_UID "referred.uid"
+#define MICROFEED_ITEM_PROPERTY_NAME_USER_NAME "user.name"
+#define MICROFEED_ITEM_PROPERTY_NAME_USER_NICK "user.nick"
+#define MICROFEED_ITEM_PROPERTY_NAME_USER_FEED "user.feed"
+#define MICROFEED_ITEM_PROPERTY_NAME_USER_URL "user.url"
+#define MICROFEED_ITEM_PROPERTY_NAME_REFERRED_ITEM "referred.item"
+#define MICROFEED_ITEM_PROPERTY_NAME_REFERRED_FEED "referred.feed"
+#define MICROFEED_ITEM_PROPERTY_NAME_COMMENTS_COUNT "comments.count"
+#define MICROFEED_ITEM_PROPERTY_NAME_COMMENTS_FEED "comments.feed"
+
 #define MICROFEED_ITEM_PROPERTY_NAME_SETTING_LENGTH "setting.length"
 #define MICROFEED_ITEM_PROPERTY_NAME_SETTING_TEXT "setting.text"
 #define MICROFEED_ITEM_PROPERTY_NAME_SETTING_TYPE "setting.type"
 #define MICROFEED_ITEM_PROPERTY_NAME_SETTING_UNIT "setting.unit"
 #define MICROFEED_ITEM_PROPERTY_NAME_SETTING_VALUE "setting.value"
-#define MICROFEED_ITEM_PROPERTY_NAME_FEED_PERMISSION "feed.permission"
 #define MICROFEED_ITEM_PROPERTY_NAME_FEED_NAME "feed.name"
+#define MICROFEED_ITEM_PROPERTY_NAME_FEED_PERMISSION "feed.permission"
 
 #define MICROFEED_PUBLISHER_IDENTIFIER_SEPARATOR_CHAR '-'
 #define MICROFEED_PUBLISHER_IDENTIFIER_SEPARATOR_STRING "-"
