@@ -51,7 +51,7 @@ typedef void* (*MicrofeedThreadFunction)(void* data);
 typedef void (*MicrofeedThreadExitCallback)(MicrofeedThread* thread, void* user_data);
 
 typedef struct {
-	void* (*thread_new)(MicrofeedThreadFunction function, void* data);
+	void* (*thread_new)(void* (*function)(void* data), void* data);
 	void (*thread_free)(void* thread_implementation);
 	void* (*thread_get_current)(void);
 	void (*thread_send_signal)(void* thread_implementation, int signal_number);
@@ -75,11 +75,11 @@ void microfeed_thread_unref(MicrofeedThread* thread);
 
 MicrofeedThread* microfeed_thread_get_current(void);
 void microfeed_thread_send_signal(MicrofeedThread* thread, int signal_number);
-void microfeed_thread_join(MicrofeedThread* thread);
 unsigned long microfeed_thread_get_id(MicrofeedThread* thread);
 
 MicrofeedThreadPool* microfeed_thread_pool_new(unsigned int maximum_thread_count);
 MicrofeedThreadPool* microfeed_thread_pool_new_with_exit_callback(unsigned int max_threads, MicrofeedThreadExitCallback exit_callback, void* user_data);
+void microfeed_thread_pool_free(MicrofeedThreadPool* thread_pool);
 MicrofeedThread* microfeed_thread_pool_queue_thread(MicrofeedThreadPool* thread_pool, MicrofeedThreadFunction function, void* data);
 MicrofeedThread* microfeed_thread_pool_queue_thread_with_exit_callback(MicrofeedThreadPool* thread_pool, MicrofeedThreadFunction function, void* data, MicrofeedThreadExitCallback exit_callback, void* user_data);
 unsigned int microfeed_thread_pool_get_started_thread_count(MicrofeedThreadPool* thread_pool);
