@@ -1037,7 +1037,7 @@ static MicrofeedError* method_store_data(MicrofeedPublisher* publisher, Subscrib
 	if (data_size > sizeof(Data) + url_size) {
 		path = microfeed_util_string_concatenate(publisher->data_directory, ((void*)data) + sizeof(Data) + data->url_length, NULL);
 		if (microfeed_util_file_exists(path)) {
-			microfeed_provider_send_data_stored_signal(publisher->provider, subscriber->unique_connection_name, publisher->object_path, url, data + sizeof(uint64_t));
+			microfeed_provider_send_data_stored_signal(publisher->provider, subscriber->unique_connection_name, publisher->object_path, url, ((void*)data) + sizeof(Data) + data->url_length);
 			free(data);
 			free(path);
 			
@@ -1073,7 +1073,7 @@ static MicrofeedError* method_store_data(MicrofeedPublisher* publisher, Subscrib
 
 		data_size = sizeof(Data) + url_size + strlen(name) + 1;
 		data = realloc(data, data_size);
-		memcpy(data, name, data_size - sizeof(Data) - url_size);
+		memcpy(((void*)data) + sizeof(Data) + url_size, name, data_size - sizeof(Data) - url_size);
 		microfeed_database_index_replace_data(publisher->data_index, data, data_size);
 
 		microfeed_provider_send_data_stored_signal(publisher->provider, NULL, publisher->object_path, url, name);
